Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(536)

Unified Diff: chrome/browser/chrome_browser_main.cc

Issue 143003020: Move TranslateLanguageList to the Translate component (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@removeDelegate
Patch Set: rebase Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/extensions/api/preference/preference_api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/chrome_browser_main.cc
diff --git a/chrome/browser/chrome_browser_main.cc b/chrome/browser/chrome_browser_main.cc
index 95b8f1881079f89ce3089dc9aa85e7207fd99734..75213279ac3d721a793c0673d6977a898ac64ad1 100644
--- a/chrome/browser/chrome_browser_main.cc
+++ b/chrome/browser/chrome_browser_main.cc
@@ -90,7 +90,6 @@
#include "chrome/browser/profiles/profiles_state.h"
#include "chrome/browser/shell_integration.h"
#include "chrome/browser/three_d_api_observer.h"
-#include "chrome/browser/translate/translate_manager.h"
#include "chrome/browser/translate/translate_service.h"
#include "chrome/browser/ui/app_list/app_list_service.h"
#include "chrome/browser/ui/browser.h"
@@ -118,6 +117,7 @@
#include "components/nacl/browser/nacl_browser.h"
#include "components/nacl/browser/nacl_process_host.h"
#include "components/startup_metric_utils/startup_metric_utils.h"
+#include "components/translate/core/browser/translate_download_manager.h"
#include "content/public/browser/browser_thread.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
@@ -1552,8 +1552,7 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
UMA_HISTOGRAM_LONG_TIMES_100("Startup.BrowserOpenTabs", delay);
// If we're running tests (ui_task is non-null), then we don't want to
// call FetchLanguageListFromTranslateServer or
// StartRepeatedVariationsSeedFetch.
if (parameters().ui_task == NULL) {
// Request new variations seed information from server.
chrome_variations::VariationsService* variations_service =
@@ -1566,8 +1565,7 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
#endif
}
- TranslateManager::GetInstance()->FetchLanguageListFromTranslateServer(
- profile_->GetPrefs());
+ TranslateDownloadManager::RequestLanguageList(profile_->GetPrefs());
}
run_message_loop_ = true;
« no previous file with comments | « no previous file | chrome/browser/extensions/api/preference/preference_api.cc » ('j') | no next file with comments »
@@ -1552,8 +1552,7 @@ int ChromeBrowserMainParts::PreMainMessageLoopRunImpl() {
UMA_HISTOGRAM_LONG_TIMES_100("Startup.BrowserOpenTabs", delay);
// If we're running tests (ui_task is non-null), then we don't want to
- // call FetchLanguageListFromTranslateServer or
- // StartRepeatedVariationsSeedFetch.
+ // call RequestLanguageList or StartRepeatedVariationsSeedFetch.
if (parameters().ui_task == NULL) {
// Request new variations seed information from server.

Powered by Google App Engine
This is Rietveld 408576698